@@ -2,13 +2,9 @@
 Curses PLus is an extension to the curses module that provides some useful featues. This library will be distributed as part of many Enderbyte Programs software
 (c) 2022-2023 Enderbyte Programs, no rights reserved
 
-Current Version: 1.2.0
+Current Version: 1.2.1
 What's New:
--Add Log to ProgressBar class
--Add WaitForKeyPress to ProgressBar class (default false)
--Log is default false
--Add to log with appendlog(text,colour)
--colour is curses.color-pair() value. NOTE: You must pass it through color_pair() before giving it to appendlog().
+-Optionally add submsg to log in ProgressBar class
 """
 
 import curses#Depends on windows-curses on win32
@@ -16,6 +12,7 @@ from curses.textpad import rectangle, Textbox
 import os
 from time import sleep
 import random
+from glob import glob
 
 class Config:
     autoloadcolours = False
@@ -288,10 +285,12 @@ class ProgressBar:
                     self.screen.addstr(lx+5,1,val[0:self.mx-2],self.lclist[lx])
                     lx += 1
         self.screen.refresh()
-    def step(self,message: str = ""):
-        """Perform step of self.stepval (default 1). Sets message to message"""
+    def step(self,message: str = "",addmsgtolog:bool = False):
+        """Perform step of self.stepval (default 1). Sets message to message. Optionally adds message to log"""
         self.value += self.stepval
         self.submsg = message
+        if addmsgtolog:
+            self.appendlog(message)
         self.update()
     def done(self):
         """Mark progress bar as complete. Optionally waits for keypress. Control with self.wfkp(bool)"""
@@ -306,7 +305,19 @@ class ProgressBar:
         self.loglist.append(text)
         self.lclist.append(colour)
         self.update()
-        
+"""
+class FileDialog:
+    @staticmethod #Declare static method
+    def openfiledialog(stdscr,filter = ["*"],defaultdirectory=os.getcwd(),title="Please choose a file") -> str:
+        while True:
+            mx,my = os.get_terminal_size()
+            stdscr.erase()
+            filline(stdscr,0,10)
+            stdscr.addstr(0,0,title[0:mx-1])
+
+            stdscr.refresh()
+            ch = stdscr.getch()
+"""       
 
     
 
@@ -316,15 +327,14 @@ class ProgressBar:
 
 def __test__(stdscr):
     import random
-    from time import sleep
     curses.curs_set(0)
     load_colours(False)
     displayops(stdscr,[str(random.randint(1,1000)) for _ in range(1000)],"Hi every body")
     rlist = [str(random.randint(1,999999)) for _ in range(random.randint(100,10000))]
     p = ProgressBar(stdscr,len(rlist),1,True,True,"Example Progress Bar",True)
     for i in rlist:
-        p.step(str(i))
-        p.appendlog(str(i),curses.color_pair(random.randint(1,12)))
+        p.step(str(i),True)
+        #p.appendlog(str(i),curses.color_pair(random.randint(1,12)))
     p.done()
     del p
 
